<?php

namespace Drupal\phone_international\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'phone_international_widget' widget.
 *
 * @FieldWidget(
 *   id = "phone_international_widget",
 *   module = "phone_international",
 *   label = @Translation("Text field"),
 *   field_types = {
 *     "phone_international"
 *   }
 * )
 */
class PhoneInternationalDefaultWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element['value'] = $element + [
      '#type' => 'tel',
      '#default_value' => isset($items[$delta]->value) ? $items[$delta]->value : NULL,
      '#attributes' => [
        'class' => ['phone_international-number'],
      ],
      '#element_validate' => [
        [$this, 'PhoneValidate'],
      ],
      '#attached' => [
        'library' => ['phone_international/phone_international'],
      ],
    ];

    // Get Module path to load utilsTellInput.js.
    $module_handler = \Drupal::service('module_handler');
    $module_path = $module_handler->getModule('phone_international')->getPath();
    $element['#attached']['drupalSettings']['phone_international']['path'] = $module_path;

    return $element;
  }


  /**
   * Validate the international phone field.
   *
   * @param $element
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   */
  public function PhoneValidate($element, FormStateInterface $form_state) {
    $value = $form_state->getValue($element['#parents']);
    if ($value !== '' && !\Drupal::service('phone_international.validate')->isValidNumber($value)) {
      $form_state->setError($element, t('The %name "%phone_international" is not valid.', ['%phone_international' => $value, '%name' => $element['#title']]));
    }
  }

}
